==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MPO_poly.h <==
/* $Date: 1997/10/07 06:52:12 $  $Author: kg $  $Revision: 1.9 $ */

/**************************************************************************/
/* FILE:             MPO_poly.h                                           */
/* Autor:            Klaus Gottheil                                       */
/* Erstellt:         28/01/93                                             */
/* Letzte Aenderung: 26/10/94                                             */
/**************************************************************************/

#ifndef __MPO_poly__
#define __MPO_poly__


#define MPOC_PRINT 0
#define MPOC_SUBS  1

void	  MPO_init(VOID);
void	  MPO_reset(VOID);
void	  MPO_exit(VOID);

S_Pointer MPO_eval_poly(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_expr(S_Pointer, long, long, S_Pointer);

S_Pointer MPO_eval_degree(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_ldegree(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_degreevec(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_lcoeff(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_lterm(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_lmonomial(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_tcoeff(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_nthcoeff(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_nthterm(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_nthmonomial(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_nterms(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_coeff(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_mapcoeffs(S_Pointer, long, long, S_Pointer);

S_Pointer MPO_eval_divide(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_pdivide(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_icontent(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_norm(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_evalp(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_iszero(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_multcoeffs(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_genpoly(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_Dpoly(S_Pointer, long, long, S_Pointer);

S_Pointer MPO_eval_plus(S_Pointer, long, long);
S_Pointer MPO_eval_mult(S_Pointer, long, long);
S_Pointer MPO_eval_power(S_Pointer, long);
S_Pointer MPO_diff_poly(S_Pointer, S_Pointer, S_Pointer, S_Pointer*);
long	  MPO_cmp_types(S_Pointer, S_Pointer);
long	  MPO_equal_types(S_Pointer, S_Pointer);

void      MPO_negate(S_Pointer);
S_Pointer MPO_expr(S_Pointer, MUPbool, MUPbool);
S_Pointer MPO_poly_expr(S_Pointer, long);
#ifdef MPO_DO_SIMPLIFY
S_Pointer MPO_simplify(S_Pointer, long, long);
#endif

#endif /* __MPO_poly__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MPO_poly.h <==
/* $Date: 1999/09/29 08:09:21 $  $Author: kg $  $Revision: 1.6 $ */

/**************************************************************************/
/* FILE:             MPO_poly.h                                           */
/* Autor:            Klaus Gottheil                                       */
/* Erstellt:         28/01/93                                             */
/* Letzte Aenderung: 26/10/94                                             */
/**************************************************************************/

#ifndef __MPO_poly__
#define __MPO_poly__


#define MPOC_PRINT 0
#define MPOC_SUBS  1

void	  MPO_init();
void	  MPO_reset();
void	  MPO_exit();

S_Pointer MPO_eval_poly(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_expr(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_poly2list(S_Pointer, long, long, S_Pointer);

S_Pointer MPO_eval_degree(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_ldegree(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_degreevec(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_lcoeff(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_lterm(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_lmonomial(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_tcoeff(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_nthcoeff(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_nthterm(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_nthmonomial(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_nterms(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_coeff(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_mapcoeffs(S_Pointer, long, long, S_Pointer);

S_Pointer MPO_eval_divide(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_pdivide(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_icontent(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_norm(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_evalp(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_iszero(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_multcoeffs(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_genpoly(S_Pointer, long, long, S_Pointer);
S_Pointer MPO_eval_Dpoly(S_Pointer, long, long, S_Pointer);

S_Pointer MPO_eval_plus(S_Pointer, long, long);
S_Pointer MPO_eval_mult(S_Pointer, long, long);
S_Pointer MPO_eval_power(S_Pointer, long);
S_Pointer MPO_diff_poly(S_Pointer, S_Pointer, S_Pointer, S_Pointer*);
long	  MPO_cmp_types(S_Pointer, S_Pointer);
long	  MPO_equal_types(S_Pointer, S_Pointer);

void      MPO_negate(S_Pointer);
S_Pointer MPO_expr(S_Pointer, bool, bool);
S_Pointer MPO_poly_expr(S_Pointer, long);

#endif /* __MPO_poly__ */
